from distutils.core import setup

setup(
	name		= "listinho",
	version		= "1.2.0",
	py_modules	= ["listinho"],
	author		= "visionzpy",
	author_email	= "uniquesouljah.11@gmail.com",
	url		= "https://pypi.org/",
	description	= "A simple printer of nested lists",
	)